@@ -197,6 +197,13 @@ def fill_check_subparser(subparsers):
         action="store_true",
         help="show warnings even if they have inline suppression comments",
     )
+    check_parser.add_argument(
+        # old option maintained for backwards-compatibility
+        "--no-shellcheck",
+        dest="shellcheck",
+        action="store_false",
+        help=SUPPRESS,
+    )
     return check_parser
 
 
@@ -207,11 +214,14 @@ def check(
     strict=False,
     show_all=False,
     suppress=None,
+    shellcheck=True,
     **kwargs,
 ):
     from . import Lint
 
     suppress = set(suppress.split(",")) if suppress else set()
+    if not shellcheck:
+        suppress.add("CommandShellCheck")
 
     # Load the document (read, parse, and typecheck)
     if "CommandShellCheck" in suppress:
@@ -1258,7 +1268,7 @@ def run_self_test(**kwargs):
             raise exn
 
     print(
-        "\n🗹  miniwdl run_self_test OK; try `miniwdl configure` to set common options or show current selections.",
+        "\nminiwdl run_self_test OK; try `miniwdl configure` to set common options or show current selections.",
         file=sys.stderr,
     )
     if os.geteuid() == 0:
